From: Marc Yang <[email protected]>

200ms is the requirement to allow VDD1.1 and VDD1.8 to
drop to have proper reset.

Signed-off-by: Cathy Luo <[email protected]>
Signed-off-by: Marc Yang <[email protected]>
Signed-off-by: Amitkumar Karwar <[email protected]>
---
 drivers/net/wireless/mwifiex/sdio.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/net/wireless/mwifiex/sdio.c 
b/drivers/net/wireless/mwifiex/sdio.c
index 274a1b2..4e8aedd 100644
--- a/drivers/net/wireless/mwifiex/sdio.c
+++ b/drivers/net/wireless/mwifiex/sdio.c
@@ -1958,8 +1958,8 @@ static void mwifiex_sdio_card_reset_work(struct 
mwifiex_adapter *adapter)
 
        pr_err("Resetting card...\n");
        mmc_remove_host(target);
-       /* 20ms delay is based on experiment with sdhci controller */
-       mdelay(20);
+       /* 200ms delay is based on experiment with sdhci controller */
+       mdelay(200);
        target->rescan_entered = 0; /* rescan non-removable cards */
        mmc_add_host(target);
 }
-- 
1.8.1.4

--
To unsubscribe from this list: send the line "unsubscribe linux-wireless" in
the body of a message to [email protected]
More majordomo info at  http://vger.kernel.org/majordomo-info.html

Reply via email to